@@ -6,11 +6,10 @@ use strict;
 use vars qw[ $VERSION %LEVELS ];
 
 use base qw( Log::Dispatch::Base );
-use fields qw( outputs callbacks );
 
 use Carp ();
 
-$VERSION = '2.00';
+$VERSION = '2.01';
 
 1;
 
@@ -29,11 +28,11 @@ sub new
 {
     my $proto = shift;
     my $class = ref $proto || $proto;
-    my %params = @_;
+    my %p = @_;
 
     my $self = bless {}, $class;
 
-    my @cb = $self->_get_callbacks(%params);
+    my @cb = $self->_get_callbacks(%p);
     $self->{callbacks} = \@cb if @cb;
 
     return $self;
@@ -64,40 +63,40 @@ sub remove
 sub log
 {
     my $self = shift;
-    my %params = @_;
+    my %p = @_;
 
-    $params{message} = $self->_apply_callbacks(%params)
+    $p{message} = $self->_apply_callbacks(%p)
 	if $self->{callbacks};
 
     foreach (keys %{ $self->{outputs} })
     {
-	$params{name} = $_;
-	$self->_log_to(%params);
+	$p{name} = $_;
+	$self->_log_to(%p);
     }
 }
 
 sub log_to
 {
     my $self = shift;
-    my %params = @_;
+    my %p = @_;
 
-    $params{message} = $self->_apply_callbacks(%params)
+    $p{message} = $self->_apply_callbacks(%p)
 	if $self->{callbacks};
 
-    $self->_log_to(%params);
+    $self->_log_to(%p);
 }
 
 sub _log_to
 {
     my $self = shift;
-    my %params = @_;
-    my $name = delete $params{name};
+    my %p = @_;
+    my $name = $p{name};
 
     if (exists $self->{outputs}{$name})
     {
 	$self->{outputs}{$name}->log(@_);
     }
-    else
+    elsif ($^W)
     {
 	Carp::carp("Log::Dispatch::* object named '$name' not in dispatcher\n");
     }
@@ -167,7 +166,7 @@ message!
 
 Adds a new a Log::Dispatch::* object to the dispatcher.  If an object
 of the same name already exists, then that object is replaced.  A
-warning will be issued if the 'C<-w>' flag is set.
+warning will be issued if the C<$^W> is true.
 
 NOTE: This method can really take any object that has methods called
 'name' and 'log'.
@@ -249,10 +248,10 @@ is also acceptable.
 
 =head1 USAGE
 
-This logging system is designed to be used as a one-stop logging
-system.  In particular, it was designed to be easy to subclass so that
-if you want to handle messaging in a way other than one of the modules
-used here, you should be able to implement this with minimal effort.
+This module is designed to be used as a one-stop logging system.  In
+particular, it was designed to be easy to subclass so that if you want
+to handle messaging in a way not implemented in this package, you
+should be able to add this with minimal effort.
 
 The basic idea behind Log::Dispatch is that you create a Log::Dispatch
 object and then add various logging objects to it (such as a file
@@ -262,16 +261,14 @@ which in turn decide whether or not to accept the message and what to
 do with it.
 
 This makes it possible to call single method and send a message to a
-log file, via email, to the screen, and anywhere else all in one
-simple command.
+log file, via email, to the screen, and anywhere else, all with very
+little code needed on your part, once the dispatching object has been
+created.
 
 The logging levels that Log::Dispatch uses are borrowed from the
 standard UNIX syslog levels, except that where syslog uses partial
-words ('err') Log::Dispatch also allows the use of the full word as
-well ('error').
-
-Please note that because this code uses pseudo-hashes and compile-time
-object typing that it will only run under Perl 5.005 or greater.
+words ("err") Log::Dispatch also allows the use of the full word as
+well ("error").
 
 =head2 Making your own logging objects
 
@@ -312,18 +309,23 @@ messages if you so desire.
 
 =head2 Log::Dispatch::Tk
 
-Dominique Dumont has written Log::Dispatch::Tk which allows log
-messages to show up in a window.  This code is available from CPAN.
+Dominique Dumont has written Log::Dispatch::Tk, which allows log
+messages to show up in a Tk window.
 
 =head2 Log::Dispatch::Config
 
-Allow configuration of logging via a text file similar (or so I'm
-told) to how it is done with log4j.
+Written by Tatsuhiko Miyagawa.  Allows configuration of logging via a
+text file similar (or so I'm told) to how it is done with log4j.
+
+=head2 Log::Dispatch::DBI
+
+Log::Dispatch::DBI, also written by Tatsuhiko Miyagawa.  Log output to a
+database table.
 
 =head2 Log::Agent
 
-A very different way of doing a lot of the things that Log::Dispatch
-does.
+A very different API for doing many of the same things that
+Log::Dispatch does.  Originally written by Raphael Manfredi.
 
 =head1 AUTHOR
 
@@ -332,22 +334,9 @@ Dave Rolsky, <autarch@urth.org>
 =head1 SEE ALSO
 
 Log::Dispatch::ApacheLog, Log::Dispatch::Email,
-Log::Dispatch::Email::MailSend, Log::Dispatch::Email::MailSendmail,
-Log::Dispatch::Email::MIMELite, Log::Dispatch::File,
-Log::Dispatch::Handle, Log::Dispatch::Output, Log::Dispatch::Screen,
-Log::Dispatch::Syslog
-
-Log::Dispatch::Tk, written by Dominique Dumont.  Log output to a Tk
-window.
-
-Log::Dispatch::Config, written by Miyagawa Tatsuhiko.  Configure all
-your logging via a config file, similar to log4j.
-
-Log::Dispatch::DBI, written by Miyagawa Tatsuhiko.  Log output to a
-DBI handle.
-
-Log::Agent - similar capabilities with a different interface.  If you
-like what Params::Validate does but not its 'feel' try this one
-instead.
+Log::Dispatch::Email::MailSend, Log::Dispatch::Email::MailSender,
+Log::Dispatch::Email::MailSendmail, Log::Dispatch::Email::MIMELite,
+Log::Dispatch::File, Log::Dispatch::Handle, Log::Dispatch::Output,
+Log::Dispatch::Screen, Log::Dispatch::Syslog
 
 =cut
