@@ -6,18 +6,19 @@ use Log::Dispatch::Email;
 
 use base qw( Log::Dispatch::Email );
 
+use Carp ();
 use Mail::Send;
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.14 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.17 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
 sub send_email
 {
     my $self = shift;
-    my %params = @_;
+    my %p = @_;
 
     my $msg = Mail::Send->new;
 
@@ -27,11 +28,19 @@ sub send_email
     # Does this ever work for this module?
     $msg->set('From', $self->{from}) if $self->{from};
 
-    my $fh = $msg->open;
+    eval
+    {
+	my $fh = $msg->open
+	    or die "Cannot open handle to mail program";
 
-    $fh->print( $params{message} );
+	$fh->print( $p{message} )
+	    or die "Cannot print message to mail program handle";
 
-    $fh->close;
+	$fh->close
+	    or die "Cannot close handle to mail program";
+    };
+
+    warn $@ if $@ && $^W;
 }
 
 
@@ -39,17 +48,18 @@ __END__
 
 =head1 NAME
 
-Log::Dispatch::Email::MailSend - Subclass of Log::Dispatch::Email that
-uses the Mail::Send module
+Log::Dispatch::Email::MailSend - Subclass of Log::Dispatch::Email that uses the Mail::Send module
 
 =head1 SYNOPSIS
 
   use Log::Dispatch::Email::MailSend;
 
-  my $email = Log::Dispatch::Email::MailSend->new( name => 'email',
-                                                   min_level => 'emerg',
-                                                   to => [ qw( foo@bar.com bar@baz.org ) ],
-                                                   subject => 'Oh no!!!!!!!!!!!', );
+  my $email =
+      Log::Dispatch::Email::MailSend->new
+          ( name => 'email',
+            min_level => 'emerg',
+            to => [ qw( foo@bar.com bar@baz.org ) ],
+            subject => 'Oh no!!!!!!!!!!!', );
 
   $email->log( message => 'Something bad is happening', level => 'emerg' );
 
