@@ -6,46 +6,48 @@ use Log::Dispatch::Email;
 
 use base qw( Log::Dispatch::Email );
 
-use Carp ();
 use Mail::Sendmail ();
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%02d", q$Revision: 1.15 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.19 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
 sub send_email
 {
     my $self = shift;
-    my %params = @_;
+    my %p = @_;
 
     my %mail = ( To      => (join ',', @{ $self->{to} }),
 		 Subject => $self->{subject},
-		 Message => $params{message},
+		 Message => $p{message},
 		 # Mail::Sendmail insists on having this parameter.
 		 From    => $self->{from} || 'LogDispatch@foo.bar',
 	       );
 
-    Mail::Sendmail::sendmail(%mail)
-	or Carp::carp("Error sending mail: $Mail::Sendmail::error");
+    unless ( Mail::Sendmail::sendmail(%mail) )
+    {
+	warn "Error sending mail: $Mail::Sendmail::error" if $^W;
+    }
 }
 
 __END__
 
 =head1 NAME
 
-Log::Dispatch::Email::MailSendmail - Subclass of Log::Dispatch::Email
-that uses the Mail::Sendmail module
+Log::Dispatch::Email::MailSendmail - Subclass of Log::Dispatch::Email that uses the Mail::Sendmail module
 
 =head1 SYNOPSIS
 
   use Log::Dispatch::Email::MailSendmail;
 
-  my $email = Log::Dispatch::Email::MailSendmail->new( name => 'email',
-                                                       min_level => 'emerg',
-                                                       to => [ qw( foo@bar.com bar@baz.org ) ],
-                                                       subject => 'Oh no!!!!!!!!!!!', );
+  my $email =
+      Log::Dispatch::Email::MailSendmail->new
+          ( name => 'email',
+            min_level => 'emerg',
+            to => [ qw( foo@bar.com bar@baz.org ) ],
+            subject => 'Oh no!!!!!!!!!!!', );
 
   $email->log( message => 'Something bad is happening', level => 'emerg' );
 
@@ -128,11 +130,4 @@ minimum level.
 
 Dave Rolsky, <autarch@urth.org>
 
-=head1 SEE ALSO
-
-Log::Dispatch, Log::Dispatch::ApacheLog, Log::Dispatch::Email,
-Log::Dispatch::Email::MailSend, Log::Dispatch::Email::MIMELite,
-Log::Dispatch::File, Log::Dispatch::Handle, Log::Dispatch::Output,
-Log::Dispatch::Screen, Log::Dispatch::Syslog
-
 =cut
